@@ -1,4 +1,6 @@
 from reference import Passage
 from reference import PassageCollection
+from reference import PassageDelta
 from reference import InvalidPassageException
+from reference import book_total_verses
 from reference import get_passage_text
